@@ -14,19 +14,11 @@ itself from the command line. There are two ways of running this script:
 
 """
 
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2009-2011  The IPython Development Team
-#
-#  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
-#-----------------------------------------------------------------------------
+# Copyright (c) IPython Development Team.
+# Distributed under the terms of the Modified BSD License.
 
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
 from __future__ import print_function
 
-# Stdlib
 import glob
 from io import BytesIO
 import os
@@ -35,7 +27,6 @@ import sys
 from threading import Thread, Lock, Event
 import warnings
 
-# Now, proceed to import nose itself
 import nose.plugins.builtin
 from nose.plugins.xunit import Xunit
 from nose import SkipTest
@@ -43,8 +34,8 @@ from nose.core import TestProgram
 from nose.plugins import Plugin
 from nose.util import safe_str
 
-# Our own imports
-from IPython.utils.process import is_cmd_found
+from IPython import version_info
+from IPython.utils.py3compat import bytes_to_str
 from IPython.utils.importstring import import_item
 from IPython.testing.plugin.ipdoctest import IPythonDoctest
 from IPython.external.decorators import KnownFailure, knownfailureif
@@ -52,27 +43,24 @@ from IPython.external.decorators import KnownFailure, knownfailureif
 pjoin = path.join
 
 
-#-----------------------------------------------------------------------------
-# Globals
-#-----------------------------------------------------------------------------
+# Enable printing all warnings raise by IPython's modules
+warnings.filterwarnings('default', message='.*', category=Warning, module='IPy.*')
 
 
-#-----------------------------------------------------------------------------
-# Warnings control
-#-----------------------------------------------------------------------------
+if version_info < (4,2):
+    # ignore some warnings from traitlets until 6.0
+    warnings.filterwarnings('ignore', message='.*on_trait_change is deprecated: use observe instead.*')
+    warnings.filterwarnings('ignore', message='.*was set from the constructor.*', category=Warning, module='IPython.*')
+    warnings.filterwarnings('ignore', message='.*use the instance .help string directly, like x.help.*', category=DeprecationWarning, module='IPython.*')
+else :
+    warnings.warn('iptest has been filtering out for Traitlets warnings messages, for 2 minor versions (since 4.x), please consider updating to use new API')
 
-# Twisted generates annoying warnings with Python 2.6, as will do other code
-# that imports 'sets' as of today
-warnings.filterwarnings('ignore', 'the sets module is deprecated',
-                        DeprecationWarning )
+if version_info < (6,):
+    # nose.tools renames all things from `camelCase` to `snake_case` which raise an
+    # warning with the runner they also import from standard import library. (as of Dec 2015)
+    # Ignore, let's revisit that in a couple of years for IPython 6.
+    warnings.filterwarnings('ignore', message='.*Please use assertEqual instead', category=Warning, module='IPython.*')
 
-# This one also comes from Twisted
-warnings.filterwarnings('ignore', 'the sha module is deprecated',
-                        DeprecationWarning)
-
-# Wx on Fedora11 spits these out
-warnings.filterwarnings('ignore', 'wxPython/wxWidgets release number mismatch',
-                        UserWarning)
 
 # ------------------------------------------------------------------------------
 # Monkeypatch Xunit to count known failures as skipped.
@@ -131,36 +119,16 @@ def test_for(item, min_version=None, callback=extract_version):
 
 # Global dict where we can store information on what we have and what we don't
 # have available at test run time
-have = {}
-
-have['curses'] = test_for('_curses')
-have['matplotlib'] = test_for('matplotlib')
-have['numpy'] = test_for('numpy')
-have['pexpect'] = test_for('IPython.external.pexpect')
-have['pymongo'] = test_for('pymongo')
-have['pygments'] = test_for('pygments')
-have['qt'] = test_for('IPython.external.qt')
-have['rpy2'] = test_for('rpy2')
-have['sqlite3'] = test_for('sqlite3')
-have['cython'] = test_for('Cython')
-have['oct2py'] = test_for('oct2py')
-have['tornado'] = test_for('tornado.version_info', (3,1,0), callback=None)
-have['jinja2'] = test_for('jinja2')
-have['requests'] = test_for('requests')
-have['sphinx'] = test_for('sphinx')
-have['casperjs'] = is_cmd_found('casperjs')
-
-min_zmq = (2,1,11)
-
-have['zmq'] = test_for('zmq.pyzmq_version_info', min_zmq, callback=lambda x: x())
+have = {'matplotlib': test_for('matplotlib'),
+        'pygments': test_for('pygments'),
+        'sqlite3': test_for('sqlite3')}
 
 #-----------------------------------------------------------------------------
 # Test suite definitions
 #-----------------------------------------------------------------------------
 
-test_group_names = ['parallel', 'kernel', 'kernel.inprocess', 'config', 'core',
+test_group_names = ['core',
                     'extensions', 'lib', 'terminal', 'testing', 'utils',
-                    'nbformat', 'qt', 'html', 'nbconvert'
                    ]
 
 class TestSection(object):
@@ -186,6 +154,7 @@ class TestSection(object):
 # Name -> (include, exclude, dependencies_met)
 test_sections = {n:TestSection(n, ['IPython.%s' % n]) for n in test_group_names}
 
+
 # Exclusions and dependencies
 # ---------------------------
 
@@ -200,8 +169,9 @@ if not have['matplotlib']:
 
 # lib:
 sec = test_sections['lib']
-if not have['zmq']:
-    sec.exclude('kernel')
+sec.exclude('kernel')
+if not have['pygments']:
+    sec.exclude('tests.test_lexers')
 # We do this unconditionally, so that the test suite doesn't import
 # gtk, changing the default encoding and masking some unicode bugs.
 sec.exclude('inputhookgtk')
@@ -221,41 +191,13 @@ if sys.platform == 'win32':
     sec.exclude('plugin.test_exampleip')
     sec.exclude('plugin.dtexample')
 
-# terminal:
-if (not have['pexpect']) or (not have['zmq']):
-    test_sections['terminal'].exclude('console')
-
-# parallel
-sec = test_sections['parallel']
-sec.requires('zmq')
-if not have['pymongo']:
-    sec.exclude('controller.mongodb')
-    sec.exclude('tests.test_mongodb')
-
-# kernel:
-sec = test_sections['kernel']
-sec.requires('zmq')
-# The in-process kernel tests are done in a separate section
-sec.exclude('inprocess')
-# importing gtk sets the default encoding, which we want to avoid
-sec.exclude('zmq.gui.gtkembed')
-if not have['matplotlib']:
-    sec.exclude('zmq.pylab')
-
-# kernel.inprocess:
-test_sections['kernel.inprocess'].requires('zmq')
+# don't run jupyter_console tests found via shim
+test_sections['terminal'].exclude('console')
 
 # extensions:
 sec = test_sections['extensions']
-if not have['cython']:
-    sec.exclude('cythonmagic')
-    sec.exclude('tests.test_cythonmagic')
-if not have['oct2py']:
-    sec.exclude('octavemagic')
-    sec.exclude('tests.test_octavemagic')
-if not have['rpy2'] or not have['numpy']:
-    sec.exclude('rmagic')
-    sec.exclude('tests.test_rmagic')
+# This is deprecated in favour of rpy2
+sec.exclude('rmagic')
 # autoreload does some strange stuff, so move it to its own test section
 sec.exclude('autoreload')
 sec.exclude('tests.test_autoreload')
@@ -263,44 +205,13 @@ test_sections['autoreload'] = TestSection('autoreload',
         ['IPython.extensions.autoreload', 'IPython.extensions.tests.test_autoreload'])
 test_group_names.append('autoreload')
 
-# qt:
-test_sections['qt'].requires('zmq', 'qt', 'pygments')
-
-# html:
-sec = test_sections['html']
-sec.requires('zmq', 'tornado', 'requests', 'sqlite3')
-# The notebook 'static' directory contains JS, css and other
-# files for web serving.  Occasionally projects may put a .py
-# file in there (MathJax ships a conf.py), so we might as
-# well play it safe and skip the whole thing.
-sec.exclude('static')
-sec.exclude('fabfile')
-if not have['jinja2']:
-    sec.exclude('notebookapp')
-if not have['pygments'] or not have['jinja2']:
-    sec.exclude('nbconvert')
-
-# config:
-# Config files aren't really importable stand-alone
-test_sections['config'].exclude('profile')
-
-# nbconvert:
-sec = test_sections['nbconvert']
-sec.requires('pygments', 'jinja2')
-# Exclude nbconvert directories containing config files used to test.
-# Executing the config files with iptest would cause an exception.
-sec.exclude('tests.files')
-sec.exclude('exporters.tests.files')
-if not have['tornado']:
-    sec.exclude('nbconvert.post_processors.serve')
-    sec.exclude('nbconvert.post_processors.tests.test_serve')
 
 #-----------------------------------------------------------------------------
 # Functions and classes
 #-----------------------------------------------------------------------------
 
 def check_exclusions_exist():
-    from IPython.utils.path import get_ipython_package_dir
+    from IPython.paths import get_ipython_package_dir
     from IPython.utils.warn import warn
     parent = os.path.dirname(get_ipython_package_dir())
     for sec in test_sections:
@@ -354,8 +265,9 @@ class ExclusionPlugin(Plugin):
 class StreamCapturer(Thread):
     daemon = True  # Don't hang if main thread crashes
     started = False
-    def __init__(self):
+    def __init__(self, echo=False):
         super(StreamCapturer, self).__init__()
+        self.echo = echo
         self.streams = []
         self.buffer = BytesIO()
         self.readfd, self.writefd = os.pipe()
@@ -370,6 +282,8 @@ class StreamCapturer(Thread):
 
             with self.buffer_lock:
                 self.buffer.write(chunk)
+            if self.echo:
+                sys.stdout.write(bytes_to_str(chunk))
     
         os.close(self.readfd)
         os.close(self.writefd)
@@ -393,7 +307,7 @@ class StreamCapturer(Thread):
             return
 
         self.stop.set()
-        os.write(self.writefd, b'wake up')  # Ensure we're not locked in a read()
+        os.write(self.writefd, b'\0')  # Ensure we're not locked in a read()
         self.join()
 
 class SubprocessStreamCapturePlugin(Plugin):
@@ -470,10 +384,6 @@ def run_iptest():
         
 
     argv = sys.argv + [ '--detailed-errors',  # extra info in tracebacks
-
-                        '--with-ipdoctest',
-                        '--ipdoctest-tests','--ipdoctest-extension=txt',
-
                         # We add --exe because of setuptools' imbecility (it
                         # blindly does chmod +x on ALL files).  Nose does the
                         # right thing and it tries to avoid executables,
@@ -496,11 +406,19 @@ def run_iptest():
         # for nose >= 0.11, though unfortunately nose 0.10 doesn't support it.
         argv.append('--traverse-namespace')
 
-    # use our plugin for doctesting.  It will remove the standard doctest plugin
-    # if it finds it enabled
-    plugins = [ExclusionPlugin(section.excludes), IPythonDoctest(), KnownFailure(),
+    plugins = [ ExclusionPlugin(section.excludes), KnownFailure(),
                SubprocessStreamCapturePlugin() ]
     
+    # we still have some vestigial doctests in core
+    if (section.name.startswith(('core', 'IPython.core'))):
+        plugins.append(IPythonDoctest())
+        argv.extend([
+            '--with-ipdoctest',
+            '--ipdoctest-tests',
+            '--ipdoctest-extension=txt',
+        ])
+
+    
     # Use working directory set by parent process (see iptestcontroller)
     if 'IPTEST_WORKING_DIR' in os.environ:
         os.chdir(os.environ['IPTEST_WORKING_DIR'])
